aboutsummaryrefslogtreecommitdiffstats
path: root/includes/auth
diff options
context:
space:
mode:
authorjenkins-bot <jenkins-bot@gerrit.wikimedia.org>2024-05-04 12:47:59 +0000
committerGerrit Code Review <gerrit@wikimedia.org>2024-05-04 12:47:59 +0000
commite5699d2e21feff5de2d1a9a1d9911c144a243832 (patch)
treec589af32d7f93a9c0033ce4ab55298c16a8bcca0 /includes/auth
parent6e58b9cd2645d86338124351aae772096a737eb8 (diff)
parent3ed66687456c50d974e20a2cb48acf72b2ec4010 (diff)
downloadmediawikicore-e5699d2e21feff5de2d1a9a1d9911c144a243832.tar.gz
mediawikicore-e5699d2e21feff5de2d1a9a1d9911c144a243832.zip
Merge "Formally deprecate code marked with @deprecated"
Diffstat (limited to 'includes/auth')
-rw-r--r--includes/auth/AuthManager.php5
1 files changed, 4 insertions, 1 deletions
diff --git a/includes/auth/AuthManager.php b/includes/auth/AuthManager.php
index 27a501e64557..136583a558b2 100644
--- a/includes/auth/AuthManager.php
+++ b/includes/auth/AuthManager.php
@@ -310,11 +310,14 @@ class AuthManager implements LoggerAwareInterface {
/**
* Force certain PrimaryAuthenticationProviders
* @deprecated For backwards compatibility only
* @param PrimaryAuthenticationProvider[] $providers
* @param string $why
*/
public function forcePrimaryAuthenticationProviders( array $providers, $why ) {
+ wfDeprecated( __METHOD__, '1.43' );
+
$this->logger->warning( "Overriding AuthManager primary authn because $why" );
if ( $this->primaryAuthenticationProviders !== null ) {
@@ -310,11 +310,14 @@ class AuthManager implements LoggerAwareInterface {
/**
* Force certain PrimaryAuthenticationProviders
- * @deprecated For backwards compatibility only
+ *
+ * @deprecated since 1.43; for backwards compatibility only
* @param PrimaryAuthenticationProvider[] $providers
* @param string $why